Result class

Contains the element which is the research finding and its priority in order to sort it later.

Constructors

Result({required Element element, required int priority})
Creates a Result from an element and its priority.
const

Properties

element → Element
The research finding.
final
hashCode → int
The hash code for this object.
no setterinherited
priority → int
The priority of the result for sorting.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited