NormalizationSettings class

Settings for strings normalization.

Mainly used by the Normalize extension for Strings.

Constructors

NormalizationSettings({bool normalizeCase = false, bool normalizeCaseType = false, bool removeDiacritics = false})
Creates settings for strings normalization.
const
NormalizationSettings.defaults()
The defaults settings for normalizing strings
const
NormalizationSettings.from(NormalizationSettings object)
Creates a new NormalizationSettings object same as object.
NormalizationSettings.matching()
The defaults settings to normalize nothing. Can be used to test matching strings.
const

Properties

caseSensitivity → bool
Returns whether not the case is normalized.
no setter
hashCode → int
The hash code for this object.
no setterinherited
normalizeCase → bool
Whether the case must be normalized (to lower case). It means transforming all uppercased characters to lowercased characters.
final
normalizeCaseType → bool
Whether the case type must be normalized (to a classic case). It means transform camelCase or snake_case to normal case.
final
removeDiacritics → bool
Whether the diacritics must be removed of the strings. It means removing all the accents and other added symbols from the letters.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited