Normalize extension

Extends String with a function to normalize it.

on

Methods

normalize(NormalizationSettings settings) → String

Available on String, provided by the Normalize extension

Normalizes a string following the given normalization settings.
normalizeCamelCase() → String

Available on String, provided by the Normalize extension

Transforms a string in camel case to normal case.
normalizeCaseType() → String

Available on String, provided by the Normalize extension

Normalizes the case whether it is snake_case or camelCase. Conserves the case (upper or lower).
normalizeSnakeCase() → String

Available on String, provided by the Normalize extension

Transforms a string in snake case to normal case.
removeDiacritics() → String

Available on String, provided by the Normalize extension

Removes the diacritics of a string thanks to the diacritic package.