Where class

Type for the where parameter.

Inheritance

Constructors

Where({dynamic where = '*'})
const

Properties

columns → List<String>
Gets a list of the specified columns.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isGlobal → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
finalinherited

Methods

checkValidity() → void
Throws an exception when value has a wrong type.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited