SherlockSearchBar class

Inheritance

Constructors

SherlockSearchBar({Key? key, String? hintText, bool? isFullScreen, Color? dividerColor, double? elevation, Color? backgroundColor, Color? overlayColor, BorderSide? side, OutlinedBorder? shape, EdgeInsetsGeometry? padding, TextStyle? textStyle, TextStyle? hintStyle, required Sherlock sherlock, required SherlockCompletion sherlockCompletion, int? sherlockCompletionMinResults, int? sherlockCompletionMaxResults, void onSearch(String input, Sherlock sherlock)?, SherlockCompletionsBuilder completionsBuilder(BuildContext context, List<String> completions)?})
const

Properties

backgroundColor → Color?
final
completionsBuilder → SherlockCompletionsBuilder Function(BuildContext context, List<String> completions)?
final
dividerColor → Color?
final
elevation → double?
final
hashCode → int
The hash code for this object.
no setterinherited
hintStyle → TextStyle?
final
hintText → String?
final
isFullScreen → bool?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSearch → void Function(String input, Sherlock sherlock)?
final
overlayColor → Color?
final
padding → EdgeInsetsGeometry?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → OutlinedBorder?
final
sherlock → Sherlock
final
sherlockCompletion → SherlockCompletion
final
sherlockCompletionMaxResults → int?
final
sherlockCompletionMinResults → int?
final
side → BorderSide?
final
textStyle → TextStyle?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited